@@ -76,9 +76,9 @@ TEST_CASE("write bytes field") {
 
     SECTION("binary") {
         std::string data;
-        data.append(1, char(1));
-        data.append(1, char(2));
-        data.append(1, char(3));
+        data.append(1, static_cast<char>(1));
+        data.append(1, static_cast<char>(2));
+        data.append(1, static_cast<char>(3));
 
         pw.add_string(1, data);
 
@@ -91,32 +91,32 @@ TEST_CASE("write bytes field using vectored approach") {
     protozero::pbf_writer pw{buffer};
 
     SECTION("using two strings") {
-        std::string d1{"foo"};
-        std::string d2{"bar"};
+        const std::string d1{"foo"};
+        const std::string d2{"bar"};
 
         pw.add_bytes_vectored(1, d1, d2);
     }
 
     SECTION("using a string and a dataview") {
-        std::string d1{"foo"};
-        std::string d2{"bar"};
-        protozero::data_view dv{d2};
+        const std::string d1{"foo"};
+        const std::string d2{"bar"};
+        const protozero::data_view dv{d2};
 
         pw.add_bytes_vectored(1, d1, dv);
     }
 
     SECTION("using three strings") {
-        std::string d1{"foo"};
-        std::string d2{"ba"};
-        std::string d3{"r"};
+        const std::string d1{"foo"};
+        const std::string d2{"ba"};
+        const std::string d3{"r"};
 
         pw.add_bytes_vectored(1, d1, d2, d3);
     }
 
     SECTION("with empty string") {
-        std::string d1{"foo"};
-        std::string d2{};
-        std::string d3{"bar"};
+        const std::string d1{"foo"};
+        const std::string d2{};
+        const std::string d3{"bar"};
 
         pw.add_bytes_vectored(1, d1, d2, d3);
     }
